@@ -2,12 +2,6 @@
 	Auther:		Satoshi Yasuda	7m3tjz/ad6gz
 */
 
-#include	<stdio.h>
-#include	<stdlib.h>
-#include	<string.h>
-#include	<sys/socket.h>
-#include	<netinet/in.h>
-#include	<netinet/ip.h>
 #include	"dsgwd_pi.h"
 #include	"dprs.h"
 
@@ -21,6 +15,14 @@ void	config(int argc, char **argv)
 	FILE	*config_file;
 	int	len;
 
+	/* Default value Set */
+
+	DPRS.DprsSW = FALSE;
+	DPRS.Interval = 30;
+	DPRS.Port = 14579;
+	DPRS.BeaconSend = FALSE;
+	memcpy (DPRS.AprsServerDomainName, "yasuda.jmsi.co.jp\0", 18);
+
 	if (argc == 2)
 	{
 		config_file = fopen (argv[1], "r");
@@ -120,46 +122,52 @@ void	config(int argc, char **argv)
                         {
                                 if (atoi(pnt)) DPRS.DprsStrip = TRUE;
                         }
-			else if (!memcmp (buff, "APRS_SERVER_DOMAIN_NAME", 23))
+			else if (!memcmp (buff, "DPRS_SERVER_DOMAIN_NAME", 23))
 			{
                                 memset (DPRS.AprsServerDomainName, 0x00, 128);
                                 memcpy (DPRS.AprsServerDomainName, pnt, strlen(pnt));
 			}
-                        else if (!memcmp (buff, "APRS_SERVER_PORT", 16))
+                        else if (!memcmp (buff, "DPRS_SERVER_PORT", 16))
                         {
 				DPRS.Port = htons(atoi(pnt));
                         }
-			else if (!memcmp (buff, "APRS_STATION_CALLSIGN", 21))
+			else if (!memcmp (buff, "DPRS_STATION_CALLSIGN", 21))
 			{
 				memset (DPRS.CallSign, 0x00, 8);
 				memcpy (DPRS.CallSign, pnt, strlen(pnt));
 			}
-                        else if (!memcmp (buff, "APRS_STATION_VALIDATION_CODE", 28))
+                        else if (!memcmp (buff, "DPRS_STATION_VALIDATION_CODE", 28))
                         {
 				memset (DPRS.ValidCode, 0x00, 8);
 				memcpy (DPRS.ValidCode, pnt, strlen(pnt));
                         }
-			else if (!memcmp (buff, "APRS_STATION_BEACON_INTERVAL", 28))
+			else if (!memcmp (buff, "DPRS_STATION_BEACON_INTERVAL", 28))
                         {
                                 DPRS.Interval = atoi(pnt);
                         }
-                        else if (!memcmp (buff, "APRS_STATION_COMMENT", 20))
+                        else if (!memcmp (buff, "DPRS_STATION_COMMENT", 20))
                         {
                                 memset (DPRS.Comment, 0x00, 20);
                                 memcpy (DPRS.Comment, pnt, strlen(pnt));
                         }
-                        else if (!memcmp (buff, "APRS_STATION_LATITUDE", 21))
+                        else if (!memcmp (buff, "DPRS_STATION_LATITUDE", 21))
                         {
 				DPRS.Lat = atof(pnt) * 10000;
                         }
-                        else if (!memcmp (buff, "APRS_STATION_LONGITUDE", 22))
+                        else if (!memcmp (buff, "DPRS_STATION_LONGITUDE", 22))
                         {
 				DPRS.Long = atof(pnt) * 10000;
                         }
-			else if (!memcmp (buff, "APRS_STATION_BEACON_SEND", 24))
+			else if (!memcmp (buff, "DPRS_STATION_BEACON_SEND", 24))
 			{
-				DPRS.ClientID = FALSE;
-				if (!memcmp (pnt, "ON", 2)) DPRS.ClientID = TRUE;
+				if (!memcmp (pnt, "ON", 2)) DPRS.BeaconSend = TRUE;
+			}
+			else
+			{
+				logfile = fopen (LOGFILE, "a");
+				now = time(NULL);
+				fprintf (logfile, "%24.24s Invalid command %s\n", ctime(&now), buff);
+				fclose(logfile);
 			}
 		}
 	}
