@@ -28,6 +28,9 @@
 	2014.02.18 V00.22 Added DPRS
 	2014.02.20 V00.23 Fixed bug of DPRS
 		   V00.24 Changed Config file
+	2014.02.21 V00.25 Added sending Aprs message to D-STAR rig
+	2014.02.23 V00.26 Changed from "APRS" to "DPRS" in config file
+	2014.03.05 V00.27 Bug fixed for GetDprsMessag
 */
 
 #include	"dsgwd_pi.h"
@@ -613,7 +616,7 @@ int main(int argc, const char **argv)
 
 				if (DPRS.Interval != 0)
 				{
-					if (DPRS.ClientID && ((time(NULL) - DprsBeaconTimer) >= (DPRS.Interval * 60))) DprsBeacon_Send();
+					if (DPRS.BeaconSend && ((time(NULL) - DprsBeaconTimer) >= (DPRS.Interval * 60))) DprsBeacon_Send();
 				}
 
 				if (!Msg.connectSW && !Msg.notfoundSW)			/* check the still voice message sending? */
