@@ -330,6 +330,10 @@ void	DeleteAccessCall(void)
 	{
 		if ((time(NULL) - next->acc_time) > 600)	/* 10 min. */
 		{
+			logfile = fopen (LOGFILE, "a");
+			now = time(NULL);
+			fprintf (logfile, "%24.24s Delete from Access Table %8.8s\n", ctime(&now), next->CallSign);
+			fclose(logfile);
 			if (save)
 			{
 				save->Next = next->Next;
